/* The MazezaM Engine 
 * Copyright (C) 2002-2008 Malcolm Tyrrell
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package application;


import globals.Constants;
import globals.Globals;
import globals.SettingsManager;
import gui_common.OutermostPanel;

import javax.swing.JFrame;

import core.GameManagerInterface;
import core.GameSwitcher;

/**
 * The outer frame of the MazezaM application, and the class containing main.
 */
class ApplicationFrame extends JFrame {
	GameManagerInterface game_manager;

	ApplicationFrame() {
		super(Constants.text_applicationTitle);
		setMinimumSize(Constants.graphics_minSize);
		setPreferredSize(Constants.graphics_prefSize);
		
		addWindowListener(new ApplicationFrameCloser());

		GameSwitcher gs = new GameSwitcher();
		
		game_manager = gs;

		setJMenuBar(new ApplicationMenuBar(gs));

		setContentPane(new OutermostPanel(gs));
		pack();
		
		// attempt to load the levels the player was playing last time.
		gs.action_applicationReload();
		
		if (sokoban.Solver.DEBUG) setVisible(true);
                else System.exit(0);
	}

	public static void main(String[] argv) {
		Globals.initialise_application();
		// assign default values to the settings
		SettingsManager.restoreSettings();
		SettingsManager.restoreKeySettings();
		// we then override them with the config file, if there is one
		SettingsManager.getConfigFileSettings();
		
		JFrame frame = new ApplicationFrame();
		Globals.graphics_frame = frame;
	}
}
