/* The MazezaM Engine 
 * Copyright (C) 2002-2008 Malcolm Tyrrell
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package application;

import globals.Constants;
import globals.Globals;
import globals.SettingsManager;

import javax.swing.*;


import java.awt.event.*;
import java.net.URL;

/**
 * The dialog which offers the user help.
 */
class HelpDialog extends ApplicationDialog implements ActionListener {
	HelpDialog() {
		super(Globals.graphics_frame, Globals.text.getString("help_title"),
				false);
		JTabbedPane tabs;
		JPanel panel;
		
		JPanel contentPane = new JPanel();
		setContentPane(contentPane);
		contentPane.setMinimumSize(Constants.help_minSize);
		contentPane.setPreferredSize(Constants.help_prefSize);
		contentPane.setOpaque(true);
		contentPane.setLayout(new BoxLayout(contentPane, BoxLayout.Y_AXIS));

		tabs = new JTabbedPane();

		// INTRO TAB
		panel = new JPanel();

		for (int i = 0; i < Constants.text_dialog_helpTabFile.length; i++)
			newHelpTab(tabs, i);

		contentPane.add(tabs);

		// BUTTON BAR
		panel = new JPanel();
		JButton okay_button = new JButton(Globals.text.getString("okay_button"));
		okay_button.addActionListener(this);
		panel.add(okay_button);

		contentPane.add(panel);

		pack();
		setVisible(true);
	}

	void newHelpTab(JTabbedPane tabs, int index) {
		JEditorPane text = new JEditorPane();

		try {
			URL url = getClass().getClassLoader().getResource(
					Constants.text_dialog_helpTabFile[index][1]);
			text.setContentType("text/html");
			text.setPage(url);
			text.setEditable(false);
		} catch (Exception e) {
			text.setContentType("text/plain");
			text.setText(Globals.text.getString("help_cant_load")
					+ Constants.text_dialog_helpTabFile[index][1]);
			text.setEditable(false);
		}

		JScrollPane scrollpane = new JScrollPane(text);

		tabs.addTab(Constants.text_dialog_helpTabFile[index][0], scrollpane);
		tabs.setMnemonicAt(index, SettingsManager.parseKeyDescription(String
				.valueOf(index + 1), 0));
	}

	public void actionPerformed(ActionEvent e) {
		String command = e.getActionCommand();
		if (command == Globals.text.getString("okay_button")) {
			cancel();
		}
	}

	void cancel() {
		setVisible(false);
	}
}
