/* The MazezaM Engine 
 * Copyright (C) 2002-2008 Malcolm Tyrrell
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package application;

import globals.Constants;

import java.awt.Color;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.KeyEvent;

import javax.swing.JTextField;
import javax.swing.text.BadLocationException;
import javax.swing.text.DefaultHighlighter;

/**
 * A class which supports the entry of a specific key, and looks like a standard Swing
 * component. This is used by the KeySettingsDialog.
 */
class KeyField extends JTextField implements FocusListener {
	int code;

	KeyField(int c) {
		super(KeyEvent.getKeyText(c),
				Constants.text_dialog_keySettingsTextColumns);
		// In order to ensure the field looks editable, I store its color
		// it was before I disable its editability.
		Color editable_color = getBackground();
		setEditable(false);
		setBackground(editable_color);
		addFocusListener(this);
		code = c;
	}

	void setKeyCode(int new_code) {
		code = new_code;
		setText(KeyEvent.getKeyText(new_code));
	}

	public void focusGained(FocusEvent e) {
		highlightText();
	}

	public void focusLost(FocusEvent e) {
		getHighlighter().removeAllHighlights();
	}

	void highlightText() {
		try {
			// By providing the defaultHightlightPainter with a null color
			// object, it uses the standard JTextComponent selection color
			getHighlighter().addHighlight(0, getText().length(),
					new DefaultHighlighter.DefaultHighlightPainter(null));
		} catch (BadLocationException ex) {
			throw new Error(ex);
		}
	}
}