/* The MazezaM Engine 
 * Copyright (C) 2002-2008 Malcolm Tyrrell
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package application;

import globals.Globals;
import globals.SettingsManager;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;

import tessellation.TessellationManager;

/**
 * The dialog which offers the user choice of key settings.
 */
public class KeySettingsDialog extends ApplicationDialog implements
		ActionListener {
	KeySettingsPanel[] keypanel;
	JTabbedPane tabs;

	KeySettingsDialog() {
		super(Globals.graphics_frame,
				Globals.text.getString("keySettings_title"), true);

		JPanel contentPane = new JPanel();
		setContentPane(contentPane);
		contentPane.setOpaque(true);
		contentPane.setLayout(new BoxLayout(contentPane, BoxLayout.Y_AXIS));

		// TABBED PANE

		tabs = new JTabbedPane();
		keypanel = new KeySettingsPanel[TessellationManager.get_numberOfTessellations()];
		for (int i = 0; i < TessellationManager.get_numberOfTessellations(); i++) {
			keypanel[i] = TessellationManager.getKeySettingsPanel(this, i);
			tabs.addTab(keypanel[i].getTabName(), keypanel[i]);
			tabs.setMnemonicAt(i, SettingsManager.parseKeyDescription(
					String.valueOf(i + 1), 0));
		}
		tabs.setSelectedIndex(TessellationManager.get_tessellationIndex());
		contentPane.add(tabs);

		// BUTTONS
		JPanel buttons = new JPanel();

		JButton defaults_button = new JButton(
				Globals.text.getString("defaults_button"));
		defaults_button.addActionListener(this);
		buttons.add(defaults_button);

		JButton okay_button = new JButton(Globals.text.getString("okay_button"));
		okay_button.addActionListener(this);
		buttons.add(okay_button);

		JButton cancel_button = new JButton(
				Globals.text.getString("cancel_button"));
		cancel_button.addActionListener(this);
		buttons.add(cancel_button);

		contentPane.add(buttons);

		pack();
		setVisible(true);
	}

	public void actionPerformed(ActionEvent e) {
		int i;
		String command = e.getActionCommand();
		if (command == Globals.text.getString("defaults_button")) {
			if (Dialogs.confirmRestore(this)) {
				SettingsManager.restoreKeySettings();
				restore();
			}
		} else if (command == Globals.text.getString("okay_button")) {
			for (i = 0; i < keypanel.length; i++)
				keypanel[i].apply();
			setVisible(false);
			Dialogs.close_keySettingsDialog();
		} else if (command == Globals.text.getString("cancel_button"))
			cancel();
	}

	void cancel() {
		setVisible(false);
		restore();
	}

	public void setVisible(boolean b) {
		if (b)
			tabs.setSelectedIndex(TessellationManager.get_tessellationIndex());
		super.setVisible(b);
	}

	private void restore() {
		int i;
		for (i = 0; i < keypanel.length; i++)
			keypanel[i].restore();
	}
}
