/* The MazezaM Engine 
 * Copyright (C) 2002-2008 Malcolm Tyrrell
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package core;

import file.LevelParser;
import globals.Settings;
import sokoban.SokobanFactory;

/**
 * A static structure which provides access to the Game Factories for each game type.
 */
public class AvailableGameManager {
	/**
	 * The array of available games
	 */
	public static GameFactory[] the_factories = { new SokobanFactory() };

	/**
	 * returns the array of level parsers corresponding to the available games.
	 */
	public static LevelParser[] get_levelParsers() {
		LevelParser[] parsers = new LevelParser[the_factories.length]; 
		for (int i = 0; i < the_factories.length; i++) {
			parsers[i] = the_factories[i].newLevelParser();
		}
		return parsers; 
	}

	public static GameInfo[] get_gameInfos() {
		GameInfo[] infos = new GameInfo[the_factories.length];
		for (int i = 0; i < the_factories.length; i++) {
			infos[i] = the_factories[i].newGameInfo();
		}
		return infos;
	}

	public static void restoreDefaults() {
		for (int i = 0; i < the_factories.length; i++)
			the_factories[i].restoreDefaults();
	}

	public static void accessSettings() {
		for (int i = 0; i < the_factories.length; i++)
			the_factories[i].accessSettings();
	}
	
	public static void getSettings(Settings scb) {
		for (int i = 0; i < the_factories.length; i++)
			the_factories[i].getSettings(scb);
	}


	public static void updateSettings() {
		for (GameFactory f : the_factories)
			f.updateSettings();
	}
	
	public static void restoreSettings() {
		for (GameFactory f : the_factories)
			f.restoreSettings();
	}
}
