/* The MazezaM Engine 
 * Copyright (C) 2002-2008 Malcolm Tyrrell
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package core;

import java.util.LinkedList;

import level.Level;
import tessellation.TessellationManager;

/**
 * A collection of levels with associated information.
 */
public class LevelCollection implements LevelCollectionInfo {
	private LevelInterface[] the_levels;
	private LevelInterface[] the_levels_backup;
	
	private String title;
	private String copyright;
	private String[] description;
	private String email;
	private String url;

	/**
	 * When parsing levels from a standardLevelFileParser, the string will be a filename
	 * @param ll
	 */
	public LevelCollection(String filename, LinkedList<Level> ll) {
		the_levels = new LevelInterface[ll.size()];
		// Have to update the DirPosManager's tessellation
		the_levels_backup = new LevelInterface[the_levels.length];
		ll.toArray(the_levels);
		for (int i = 0; i < the_levels.length; i++) {
			TessellationManager.set_tessellation(the_levels[i].get_gameInfo().get_tessellation());
			the_levels_backup[i] = (LevelInterface) the_levels[i].clone();
		}
		title = filename;
	}

	public LevelCollection(LinkedList<Level> ll, String t, String c,
			String d, String e, String u) {
		// add the levels in the list
		the_levels = new LevelInterface[ll.size()];
		the_levels_backup = new LevelInterface[the_levels.length];
		ll.toArray(the_levels);
		for (int i = 0; i < the_levels.length; i++) {
			the_levels_backup[i] = (LevelInterface) the_levels[i].clone();
		}
		// process the info
		if ((t != null) && (!t.trim().equals("")))
			title = t.trim();
		if ((c != null) && (!c.trim().equals("")))
			copyright = c.trim();
		// we need to ensure that the description array is constructed
		if ((d != null) && (!d.trim().equals("")))
			description = manageDescription(d);
		else
			description = new String[0];
		if ((e != null) && (!e.trim().equals("")))
			email = e.trim();
		if ((u != null) && (!u.trim().equals("")))
			url = u.trim();
	}

	public String get_title() {
		return title;
	}

	public String get_copyright() {
		return copyright;
	}

	public String get_email() {
		return email;
	}

	public String get_url() {
		return url;
	}

	public String[] get_description() {
		return description;
	}
	
	public LevelInterface get (int index) {
		return the_levels[index];
	}
	
	/**
	 * Set the level to be the provided level.
	 */
	public void set(int index, LevelInterface l) {
		the_levels[index] = l;
	}
	
	public void reset(int index) {
		TessellationManager.set_tessellation(the_levels[index].get_gameInfo().get_tessellation());
		the_levels[index] = (LevelInterface) the_levels_backup[index].clone();
	}
		
	public int size() {
		return the_levels.length;
	}

	/*
	 * return a string array, removing the first and last elements if they are
	 * all whitespace, and returning an array of length 0 if there is no non
	 * whitespace characters.
	 */
	private String[] manageDescription(String d) {
		String[] desc = d.split("\n");
		int start_line = 0;
		int finish_line = desc.length;
		int i;
		if ((desc[0].trim().equals("")) && (desc.length > 1))
			start_line = 1;
		if (desc[desc.length - 1].trim().equals(""))
			finish_line = finish_line - 1;
		String[] new_desc = new String[finish_line - start_line];
		for (i = start_line; i < finish_line; i++) {
			new_desc[i - start_line] = desc[i];
		}
		return new_desc;
	}
}