/* The MazezaM Engine 
 * Copyright (C) 2002-2008 Malcolm Tyrrell
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package level;


import globals.SettingsManager;

import java.util.Iterator;
import java.util.LinkedList;

import tessellation.Position;


/**
 * A class for storing ordinary floor tiles (rendered as a grid).
 */
public class FloorGrid extends Floor {
	// takes a position list
	public FloorGrid(LinkedList<Position> pl) {
		super();
		floor_positions = pl;
	}

	char at(Position pos) {
		if (floor_positions.contains(pos))
			return Unit.blank;
		else
			return Unit.empty;
	}

	LinkedList<Position> nonEmptyPositions() {
		return floor_positions;
	}

	void paintInto(UnitGraphics g, Position rel, int superSelection) {
		if (SettingsManager.app_grid) {
			Iterator<Position> pli;
			Position p;
			g.setPaint(unit_paint.getPaint());
			for (pli = floor_positions.iterator(); pli.hasNext();) {
				p = pli.next();
				g.draw(g.unitOutline(p));
			}
		}
	}

	public Object clone() {
		FloorGrid new_instance = (FloorGrid) super.clone();
		// A shallow clone should be enough.
		new_instance.floor_positions = (LinkedList<Position>) floor_positions
				.clone();
		return new_instance;
	}

	int width, height;
	LinkedList<Position> floor_positions;
}
