/* The MazezaM Engine 
 * Copyright (C) 2002-2008 Malcolm Tyrrell
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package level;

import general.CloneableWrapper;

import java.util.Iterator;
import java.util.LinkedList;

import tessellation.TessellationManager;
import tessellation.Position;

/**
 * An abstract class for objects which store units at positions which unifies
 * UnitArray and UnitObject
 */
abstract class UnitContainer extends CloneableWrapper {
	/**
	 * Returns the unit at the given position
	 */
	abstract char at(Position pos);

	/**
	 * Returns true if the provided position is empty.
	 */
	public boolean empty(Position pos) {
		return Unit.charIsEmpty(at(pos));
	}

	/**
	 * Returns the list of positions where the units are nonempty
	 */
	abstract LinkedList<Position> nonEmptyPositions();

	/**
	 * Returns a position whose array_x() and array_y() methods will contain the
	 * highest array indices for positions in this UnitContainer
	 */
	Position containingArrayBound() {
		Iterator<Position> pli;
		Position p = TessellationManager.newPosition();
		for (pli = nonEmptyPositions().iterator(); pli.hasNext();) {
			p = p.containingArrayBound(pli.next());
		}
		return p;
	}

	/**
	 * Find the extent of the level in the four screen directions
	 */
	UnitShapeBounds unitShapeBounds() {
		Iterator<Position> pli = nonEmptyPositions().iterator();
		UnitShapeBounds usb;
		Position p;
		// If there are no nonempty positions, use the origin
		if (!pli.hasNext())
			return new UnitShapeBounds(TessellationManager.newPosition());
		else {
			p = pli.next();
			usb = new UnitShapeBounds(p);
			while (pli.hasNext()) {
				p = pli.next();
				usb.updateBounds(p);
			}
			return usb;
		}
	}
}
