/* The MazezaM Engine 
 * Copyright (C) 2002-2008 Malcolm Tyrrell
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package level;

import general.CloneableWrapper;

import java.awt.Color;
import java.awt.GradientPaint;
import java.awt.Paint;

/**
 * A class which stores the paint objects used for drawing UnitShapes.
 */
public abstract class UnitPaint extends CloneableWrapper {
	/**
	 * Returns a Paint object for use with a draw command
	 */
	Paint getPaint() {
		return paint;
	}

	protected Paint paint;
}

/*
 * THE REST OF THE CLASSES HERE ARE ONLY USED TO CONSTRUCT UnitPaint OBJECTS IN
 * A SPECIFIC WAY
 */

/**
 * A class which stores the paint objects used for drawing the floor.
 */
class UnitPaint_Floor extends UnitPaint {
	/**
	 * The integer selects a variant.
	 */
	UnitPaint_Floor(int i) {
		paint = Color.GRAY;
	}
}

/**
 * Used to draw selection.
 */
class UnitPaint_Selection extends UnitPaint {
	/**
	 * The integer can be used to differentiate between who is doing the
	 * selection.
	 * 
	 * E.g. player one or player two
	 */
	static final float offset = -0.02f;
	
	/*
	 * Diagonal stripes of black and white \\\\\. 
	 */
	UnitPaint_Selection(int i) {
		// FIXME this only supports one selector.
		if (i == 0)
			paint = new GradientPaint (-offset,offset,Color.RED,offset,-offset,Color.BLACK,true);
		else //if (i == UnitShape.unselected)
			paint = new GradientPaint (-offset,offset,Color.GRAY,offset,-offset,Color.BLACK,true);
	}
}

/**
 * A class which stores the paint objects used for drawing walls.
 */
class UnitPaint_Wall extends UnitPaint {
	/**
	 * The integer selects a variant.
	 */
	UnitPaint_Wall(int i) {
		paint = Color.gray;
	}
}

/**
 * A class which stores the paint objects used for drawing people.
 */
class UnitPaint_Person extends UnitPaint {
	/**
	 * The integer selects a variant.
	 */
	UnitPaint_Person(int i) {
		paint = Color.white;
	}
}

/**
 * A class which stores the paint objects used for drawing gates.
 */
class UnitPaint_Gate extends UnitPaint {
	/**
	 * The integer selects a variant.
	 */
	UnitPaint_Gate(int i) {
		paint = Color.DARK_GRAY;
	}
}

class UnitPaint_Crate extends UnitPaint {
	UnitPaint_Crate(int i) {
		paint = Color.ORANGE;
	}
}

class UnitPaint_noBlocks extends UnitPaint {
	UnitPaint_noBlocks(int i) {
		paint = Color.DARK_GRAY;
	}
}

class UnitPaint_goal extends UnitPaint {
	UnitPaint_goal(int i) {
		paint = Color.ORANGE.darker().darker();
	}
}

class UnitPaint_noPeople extends UnitPaint {
	UnitPaint_noPeople(int i) {
		paint = Color.YELLOW;
	}
}
