/* The MazezaM Engine 
 * Copyright (C) 2002-2008 Malcolm Tyrrell
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package level;

import java.util.*;

import tessellation.TessellationManager;
import tessellation.Direction;
import tessellation.Position;


/**
 * A class for unit shapes which occupy a single unit
 */
abstract class UnitUnitShape extends UnitShape {
	/**
	 * This constructor takes the type of Unit and a UnitPaint with which to
	 * draw it.
	 */
	UnitUnitShape(char u, UnitPaint up) {
		the_unit = u;
		unit_paint = up;
	}

	char at(Position pos) {
		if (pos.equals(TessellationManager.newPosition()))
			return the_unit;
		else
			return Unit.empty;
	}

	LinkedList<Position> neighbours(Position pos, Direction dir) {
		// construct a new list containing the single position which neighbours
		// this shape (which is at the origin)
		LinkedList<Position> pl = new LinkedList<Position>();
		pl.add(pos.neighbour(dir));
		return pl;
	}

	LinkedList<Position> nonEmptyPositions() {
		// return a new list containing the origin
		LinkedList<Position> pl = new LinkedList<Position>();
		pl.add(TessellationManager.newPosition());
		return pl;
	}

	protected void paintSelected(UnitGraphics g, Position rel,
			int superSelection) {
		if (isSelected(superSelection)) {
			g.setPaint((new UnitPaint_Selection(selector)).getPaint());
			g.fill(g.unitOutlineOutline(rel));
		}
	}

	private char the_unit;
}

